pub fn try_parse_cid(s: &str) -> Option<ParsedCid>Expand description
Parses s as a CID, returning None if it is not a valid CID string.
Accepts CIDv0 and multibase CID strings up to MAX_CID_STRING_LEN. Paths,
non-minimal binary encodings, and trailing decoded bytes are rejected.